#!/usr/bin/perl -I/tmp/4f/lib/4f

# --------------------------------------------------------------------
# 4F - Formula for Form Fabrication
#
#                                            http://www.godtomato.net/
#                                         mailto:takefumi@takefumi.com
#             Copyright (c) 1997-2002 GOD TOMATO. All rights reserved.
# --------------------------------------------------------------------
use strict;
use FFFF;
use Data::Dumper;

	#
	# FORMβϡ֥Ȥκ
	#
    my $ffff = FFFF->new();

	eval {
		#
		# եɤ߹
		#
		$ffff->readconfig();

		#
		# åɤ߹ߤ¸
		#
		$ffff->session_set();

		#
		# _action ꤵƤʤäꡢ
		# _back ꤵƤСϥåʤɤϾʤ
		#
		if ($ffff->{ACTION} ne "" and $ffff->{BACK} eq "") {

			#
			# ϥå
			#
			$ffff->session_check();
			$ffff->input_check();

			if($ffff->is_error() == 0) {
				#
				# ⥸塼¹
				#
				$ffff->exec_module();

				#
				# åκ
				#
				if ($ffff->{CONFIG_NOW}->{SESSION_EXPIRE} == 1) {
					$ffff->session_expire();
				}
			}
		}

		#
		# HTMLν
		#
		$ffff->outputhtml();
	};

	#
	# 顼
	#
	if ($@) {
		print "Contnt-Type: text/html\n\n";
        $@ =~ s/&/&amp;/g;
        $@ =~ s/</&lt;/g;
        $@ =~ s/>/&gt;/g;
        $@ =~ s/\"/&quot;/g;
		print "SYSTEM ERR: <PRE>$@</PRE>";
	}

	#
	# ǥХåν
	#
	if ($ffff->{CONFIG}->{DEBUG} == 1) {
		print "<pre>";
		print "<hr>ACTION: " . $ffff->{FORM}->{_action};
		print "<hr>ERROR: "  . Dumper $ffff->{ERROR};
		print "<hr>DUMP: "   . Dumper $ffff;
		print "</pre>";
	}
__END__
=head CHANGES
0.0.3   2002/05/15
	- 顼 HTML ׽ɲ

0.0.2   2002/05/14
    - ǥХåˡߤACTIONERROR褻褦ˤ
      פȸˤΤǡ

0.0.1   2002/05/09
    - original version
=cut
